pub struct GraphicalTheme { /* private fields */ }Expand description
Theme used by GraphicalReportHandler.
Use one of the predefined constructors below.
Implementations
Sourceimpl GraphicalTheme
impl GraphicalTheme
Sourcepub fn unicode() -> Self
pub fn unicode() -> Self
Graphical theme that draws using both ansi colors and unicode characters.
Note that full rgb colors aren’t enabled by default because they’re an accessibility hazard, especially in the context of terminal themes that can change the background color and make hardcoded colors illegible. Such themes typically remap ansi codes properly, treating them more like CSS classes than specific colors.
Sourcepub fn unicode_nocolor() -> Self
pub fn unicode_nocolor() -> Self
Graphical theme that draws in monochrome, while still using unicode characters.
Sourcepub fn none() -> Self
pub fn none() -> Self
A “basic” graphical theme that skips colors and unicode characters and just does monochrome ASCII art.
Sourcepub const fn warning_style(&self) -> Style
pub const fn warning_style(&self) -> Style
Style used for warning text.